<template>
  <a-modal
    :title="title"
    :width="1250"
    :visible="visible"
    :maskClosable="false"
    @ok="handleOk"
    cancelText="关闭"
    @cancel="handleCancel"
    :confirmLoading="confirmLoading"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              label="点检工单"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入点检工单'"
                v-decorator="['num', validatorRules.num ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              label="点检日期"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <j-date
                :disabled="true"
                v-decorator="['inspectionTime', validatorRules.inspectionTime ]"
                placeholder="请选择点检时间"
                style="width: 100%"
                :showTime="true"
                dateFormat="YYYY-MM-DD HH:mm:ss"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              label="专业点检方案"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <!-- <a-input-search
                :disabled="true"
                placeholder="请选择专业点检方案"
                enter-button
                @search="onSpecialtyInspectionPlanList()"
                :read-only="true"
                v-decorator="['specialtyInspectionPlanNum', validatorRules.specialtyInspectionPlanNum]"
              /> -->
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请选择专业点检方案'"
                v-decorator="['specialtyInspectionPlanNum', validatorRules.specialtyInspectionPlanNum ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="派工方式"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请选择派工方式'"
                :triggerChange="true"
                dictCode="assign_mode"
                v-decorator="['assignMode', validatorRules.assignMode]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="责任班组"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任班组'"
                v-decorator="['teamName', validatorRules.teamName ]"
              />
            </a-form-item>
          </a-col>
          <a-col
            hidden
            :span="12"
          >
            <a-form-item
              label="专业点检方案Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'专业点检方案Id'"
                v-decorator="['specialtyInspectionPlanId', validatorRules.specialtyInspectionPlanId ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <!-- v-if="!isHidden" -->
          <a-col :span="12">
            <a-form-item
              label="责任人"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input-search
                :disabled="false"
                placeholder="责任人"
                enter-button
                @search="onDutyUserList()"
                :read-only="true"
                v-decorator="['inspectionUserName', validatorRules.inspectionUserName]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row
          hidden
          :gutter="24"
        >
          <a-col :span="12">
            <a-form-item
              label="责任班组Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任班组Id'"
                v-decorator="['teamId', validatorRules.teamId ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              label="责任人/点检人Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任人/点检人'"
                v-decorator="['inspectionUserId', validatorRules.inspectionUserId ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel()"
      >
        关闭
      </a-button>

      <a-button
        @click="handleOk()"
        type="primary"
        :loading="confirmLoading"
      >确定</a-button>
    </template>

    <specialty-inspection-plan-list
      ref="SpecialtyInspectionPlanList"
      @sendSpecialtyInspectionPlanRecord='sendSpecialtyInspectionPlanRecord'
    ></specialty-inspection-plan-list>
    <user-list
      ref="UserList"
      @sendDutyUserRecord='sendDutyUserRecord'
    ></user-list>
  </a-modal>

</template>

<script>
import { getAction, postAction, requestPut } from '@/api/manage'
import pick from 'lodash.pick'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'
import Tooltip from 'ant-design-vue/es/tooltip'
import UserList from './UserList'
import SpecialtyInspectionPlanList from './SpecialtyInspectionPlanList'

export default {
  name: "SpecialtyInspectionOrderModal",
  components: {
    JMultiSelectTag,
    Tooltip,
    UserList,
    SpecialtyInspectionPlanList
    // PdfView,
    // preview,
  },
  data() {
    return {
      title: "操作",
      visible: false,
      disableSubmit: false,
      codeDisable: true,
      model: {},
      inspectionCycles: [],
      // isHidden: true,
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        num: {
          rules: [
            { required: true, message: '请输入设备编码!' },
          ]
        },
        specialtyInspectionPlanId: {
          rules: [
            { required: true, message: '请选择点检方案!' },
          ]
        },
        inspectionTime: {
          rules: [
            { required: true, message: '请选择点检日期!' },
          ]
        },
        inspectionUserName: {
          rules: [
            { required: true, message: '请选择责任人!' },
          ]
        },
        assignMode: {
          rules: [
            { required: true, message: '请选择派工方式!' },
          ]
        },
        teamName: {
          rules: [
            { required: true, message: '请选择责任班组!' },
          ]
        },
      },
      url: {
        add: "/eam/specialtyInspectionOrder/add",
        assign: "/eam/specialtyInspectionOrder/assign",
      },
    }
  },

  methods: {
    edit(record) {
      let that = this;
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      that.$nextTick(() => {
        that.form.setFieldsValue(pick(that.model, 'num', 'specialtyInspectionPlanNum', 'specialtyInspectionPlanId', 'assignMode', 'teamId', 'teamName', 'inspectionUserId', 'inspectionUserName', 'inspectionTime'));
      });
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    handleCancel() {
      this.close();
    },

    handleOk() {
      const that = this;
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.assign, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    onSpecialtyInspectionPlanList() {
      this.$refs.SpecialtyInspectionPlanList.list();
      this.$refs.SpecialtyInspectionPlanList.title = "选择专业点检方案";
    },
    sendSpecialtyInspectionPlanRecord(data) {
      let record = data.record;
      this.form.setFieldsValue({ assignMode: null, teamName: null, teamId: null, inspectionUserName: null, inspectionUserId: null });
      this.form.setFieldsValue({ specialtyInspectionPlanId: record.id, specialtyInspectionPlanNum: record.num });
      this.form.setFieldsValue({ assignMode: record.assignMode, teamName: record.teamName, teamId: record.teamId });
    },

    onDutyUserList() {
      let data = this.form.getFieldsValue(['teamId']);
      if (data.teamId == null || data.teamId == "") {
        this.$message.warning("请先维护班组！");
        return
      }
      this.$refs.UserList.list(data.teamId);
      this.$refs.UserList.title = "选择人员";
    },
    sendDutyUserRecord(data) {
      let record = data.record;
      this.form.setFieldsValue({ inspectionUserId: record.id, inspectionUserName: record.username + "/" + record.realname });
    },


  },
}
</script>

<style lang="less" scoped>
/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.fontweight {
  font-weight: bold;
}
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>